Estimate preference score of species based on occupancy in biased sample sets
enve.prefscore(
x,
set,
ignore = NULL,
signif.thr,
plot = TRUE,
col.above = rgb(148, 17, 0, maxColorValue = 255),
col.equal = rgb(189, 189, 189, maxColorValue = 255),
col.below = rgb(47, 84, 150, maxColorValue = 255),
...
)Returns a named vector of preference scores.
Occupancy matrix (logical or numeric binary) with species as rows and samples as columns
Vector indicating samples in the test set. It can be any selection vector:
boolean (same length as the number of columns in x), or numeric or
character vector with indexes of the x columns.
Vector indicating species to ignore. It can be any selection vector with
respect to the rows in x (see set).
Absolute value of the significance threshold
Indicates if a plot should be generated
Color for points significantly above zero
Color for points not significantly different from zero
Color for points significantly below zero
Any additional parameters supported by plot
Luis M. Rodriguez-R [aut, cre]