Automatically prunes a tree, to keep representatives of each clade.
enve.prune.dist(
t,
dist.quantile = 0.25,
min_dist,
quiet = FALSE,
max_iters = 100,
min_nodes_random = 40000,
random_nodes_frx = 1
)Returns a pruned phylo object.
A phylo object or a path to the Newick file.
The quantile of edge lengths.
The minimum distance to allow between two tips.
If not set, dist.quantile is used instead to calculate it.
Boolean indicating if the function must run without output.
Maximum number of iterations.
Minimum number of nodes to trigger tip-pairs nodes sampling.
This sampling is less reproducible and more computationally expensive,
but it's the only solution if the cophenetic matrix exceeds 2^31-1
entries; above that, it cannot be represented in R.
Fraction of the nodes to be sampled if more than min_nodes_random.
Luis M. Rodriguez-R [aut, cre]