Learn R Programming

enveomics.R (version 1.9.1)

enve.recplot2.ANIr: Enveomics: Recruitment Plot (2) ANI Estimate

Description

Estimate the Average Nucleotide Identity from reads (ANIr) from a recruitment plot.

Usage

enve.recplot2.ANIr(x, range = c(0, Inf))

Value

A numeric value indicating the ANIr (as percentage).

Arguments

x

enve.RecPlot2 object.

range

Range of identities to be considered. By default, the full range is used (note that the upper boundary is Inf and not 100 because recruitment plots can also be built with bit-scores). To use only intra-population matches (with identities), use c(95, 100). To use only inter-population values, use c(0, 95).

Author

Luis M. Rodriguez-R [aut, cre]