Identifies peaks in the population histogram using a Gaussian Mixture Model Expectation Maximization (GMM-EM) method.
enve.recplot2.findPeaks.em(
x,
max.iter = 1000,
ll.diff.res = 1e-08,
components = 2,
rm.top = 0.05,
verbose = FALSE,
init,
log = TRUE
)Returns a list of enve.RecPlot2.Peak objects.
An enve.RecPlot2 object.
Maximum number of EM iterations.
Maximum Log-Likelihood difference to be considered as convergent.
Number of distributions assumed in the mixture.
Top-values to remove before finding peaks, as a quantile probability.
This step is useful to remove highly conserved regions, but can be
turned off by setting rm.top=0. The quantile is determined
after removing zero-coverage windows.
Display (mostly debugging) information.
Initialization parameters. By default, these are derived from k-means
clustering. A named list with vectors for mu, sd, and
alpha, each of length components.
Logical value indicating if the estimations should be performed in natural logarithm units. Do not change unless you know what you're doing.
Luis M. Rodriguez-R [aut, cre]