Learn R Programming

enveomics.R (version 1.9.1)

enve.recplot2.findPeaks.emauto: Enveomics: Recruitment Plot (2) Emauto Peak Finder

Description

Identifies peaks in the population histogram using a Gaussian Mixture Model Expectation Maximization (GMM-EM) method with number of components automatically detected.

Usage

enve.recplot2.findPeaks.emauto(
  x,
  components = seq(1, 5),
  criterion = "aic",
  merge.tol = 2L,
  verbose = FALSE,
  ...
)

Value

Returns a list of enve.RecPlot2.Peak objects.

Arguments

x

An enve.RecPlot2 object.

components

A vector of number of components to evaluate.

criterion

Criterion to use for components selection. Must be one of: aic (Akaike Information Criterion), bic or sbc (Bayesian Information Criterion or Schwarz Criterion).

merge.tol

When attempting to merge peaks with very similar sequencing depth, use this number of significant digits (in log-scale).

verbose

Display (mostly debugging) information.

...

Any additional parameters supported by enve.recplot2.findPeaks.em.

Author

Luis M. Rodriguez-R [aut, cre]