enve.tribs.test: Enveomics: TRIBS Test
Description
Estimates the empirical difference between all the distances in a set of
objects and a subset, together with its statistical significance.
Usage
enve.tribs.test(dist, selection, bins = 50, ...)
Value
Returns an enve.TRIBStest object.
Arguments
- dist
Distances as dist object.
- selection
Selection defining the subset.
- bins
Number of bins to evaluate in the range of distances.
- ...
Any other parameters supported by enve.tribs,
except subsamples.
Author
Luis M. Rodriguez-R [aut, cre]