Learn R Programming

enveomics.R (version 1.9.1)

enve.truncate: Enveomics: Truncate

Description

Removes the n highest and lowest values from a vector, and applies summary function. The value of n is determined such that the central range is used, corresponding to the f fraction of values.

Usage

enve.truncate(x, f = 0.95, FUN = mean)

Value

Returns the summary (FUN) of the truncated vector.

Arguments

x

A vector of numbers.

f

The fraction of values to retain.

FUN

Summary function to apply to the vectors. To obtain the truncated vector itself, use c.

Author

Luis M. Rodriguez-R [aut, cre]