Plots an enve.GrowthCurve object.
# S3 method for enve.GrowthCurve
plot(
x,
col,
pt.alpha = 0.9,
ln.alpha = 1,
ln.lwd = 1,
ln.lty = 1,
band.alpha = 0.4,
band.density = NULL,
band.angle = 45,
xp.alpha = 0.5,
xp.lwd = 1,
xp.lty = 1,
pch = 19,
new = TRUE,
legend = new,
add.params = FALSE,
...
)No return value.
An enve.GrowthCurve object to plot.
Base colors to use for the different samples. Can be recycled. By default, grey for one sample or rainbow colors for more than one.
Color alpha for the observed data points, using col
as a base.
Color alpha for the fitted growth curve, using col
as a base.
Line width for the fitted curve.
Line type for the fitted curve.
Color alpha for the confidence interval band of the
fitted growth curve, using col as a base.
Density of the filling pattern in the interval band.
If NULL, a solid color is used.
Angle of the density filling pattern in the interval
band. Ignored if band.density is NULL.
Color alpha for the line connecting individual experiments,
using col as a base.
Width of line for the experiments.
Type of line for the experiments.
Point character for observed data points.
Should a new plot be generated? If FALSE, the existing
canvas is used.
Should the plot include a legend? If FALSE, no legend
is added. If TRUE, a legend is added in the bottom-right corner.
Otherwise, a legend is added in the position specified as xy.coords.
Should the legend include the parameters of the fitted model?
Any other graphic parameters.
Luis M. Rodriguez-R [aut, cre]