Identifies peaks in the population histogram using a Gaussian Mixture Model Expectation Maximization (GMM-EM) method with number of components automatically detected.
enve.recplot2.findPeaks.emauto(
x,
components = seq(1, 5),
criterion = "aic",
merge.tol = 2L,
verbose = FALSE,
...
)Returns a list of enve.RecPlot2.Peak objects.
An enve.RecPlot2 object.
A vector of number of components to evaluate.
Criterion to use for components selection. Must be one of:
aic (Akaike Information Criterion), bic or sbc
(Bayesian Information Criterion or Schwarz Criterion).
When attempting to merge peaks with very similar sequencing depth, use this number of significant digits (in log-scale).
Display (mostly debugging) information.
Any additional parameters supported by
enve.recplot2.findPeaks.em.
Luis M. Rodriguez-R [aut, cre]