enve.selvector: Enveomics: Selection vector
Description
Normalizes a selection vector sel to a logical vector with indexes
from dim.names.
Usage
enve.selvector(sel, dim.names)
Value
Returns a logical vector with the same length as dim.name.
Arguments
- sel
A vector of numbers, characters, or booleans.
- dim.names
A vector of names from which to select.
Author
Luis M. Rodriguez-R [aut, cre]