Removes the n highest and lowest values from a vector, and applies
summary function. The value of n is determined such that the central
range is used, corresponding to the f fraction of values.
enve.truncate(x, f = 0.95, FUN = mean)Returns the summary (FUN) of the truncated vector.
A vector of numbers.
The fraction of values to retain.
Summary function to apply to the vectors. To obtain the
truncated vector itself, use c.
Luis M. Rodriguez-R [aut, cre]